@@ -121,6 +121,44 @@ def test_exceeding_max_width2():
         +----+-------+
     ''')
 
+def test_exceeding_max_width3():
+    table = Texttable()
+    table.set_max_width(35)
+    table.set_deco(Texttable.HEADER)
+    table.add_rows([
+        ["key", "value"],
+        [1,     "a"],
+        [2,     "b"],
+        [3,     "very long, very long, very long"],
+    ])
+    assert clean(table.draw()) == dedent('''\
+        key               value
+        ===================================
+        1     a
+        2     b
+        3     very long, very long, very
+              long
+    ''')
+
+def test_exceeding_max_width4():
+    table = Texttable()
+    table.set_max_width(14)
+    table.add_rows([
+        ["a", "b"],
+        [1, "+"],
+        [22, "++++++++"],
+    ])
+    assert clean(table.draw()) == dedent('''\
+        +----+-------+
+        | a  |   b   |
+        +====+=======+
+        | 1  | +     |
+        +----+-------+
+        | 22 | +++++ |
+        |    | +++   |
+        +----+-------+
+    ''')
+
 def test_obj2unicode():
     table = Texttable()
     table.set_deco(Texttable.HEADER)
@@ -217,3 +255,36 @@ def test_cjkwarp():
         ''')
     except ImportError:
         True
+
+def test_chaining():
+    table = Texttable()
+    table.reset()
+    table.set_max_width(50)
+    table.set_chars(list('-|+='))
+    table.set_deco(Texttable.BORDER)
+    table.set_header_align(list('lll'))
+    table.set_cols_align(list('lll'))
+    table.set_cols_valign(list('mmm'))
+    table.set_cols_dtype(list('ttt'))
+    table.set_cols_width([3, 3, 3])
+    table.set_precision(3)
+    table.header(list('abc'))
+    table.add_row(list('def'))
+    table.add_rows([list('ghi')], False)
+    s1 = table.draw()
+    s2 = (Texttable()
+          .reset()
+          .set_max_width(50)
+          .set_chars(list('-|+='))
+          .set_deco(Texttable.BORDER)
+          .set_header_align(list('lll'))
+          .set_cols_align(list('lll'))
+          .set_cols_valign(list('mmm'))
+          .set_cols_dtype(list('ttt'))
+          .set_cols_width([3, 3, 3])
+          .set_precision(3)
+          .header(list('abc'))
+          .add_row(list('def'))
+          .add_rows([list('ghi')], False)
+          .draw())
+    assert s1 == s2
